@@ -73,13 +73,20 @@ fi
 set -e # enable immediate exit if venv setup fails
 virtualenv --python=$PYTHON_VERSION venv
 source venv/bin/activate
+# 3.11 needs the newest pip, 3.8 and older have specific legacy get-pip urls
+PYTHON_MAJOR_MINOR=$($PYTHON_VERSION -V 2>&1 | awk '{print $2}' | cut -d. -f1,2)
+if [[ "$(printf '%s\n' "$PYTHON_MAJOR_MINOR" "3.8" | sort -V | head -n1)" == "$PYTHON_MAJOR_MINOR" ]]; then
+    curl -sS https://bootstrap.pypa.io/pip/${PYTHON_MAJOR_MINOR}/get-pip.py | $PYTHON_VERSION
+else
+    curl -sS https://bootstrap.pypa.io/get-pip.py | $PYTHON_VERSION
+fi
 
 pip install -r ${CASSANDRA_DIR}/pylib/requirements.txt
 pip freeze
 
 if [ "$cython" = "yes" ]; then
     TESTSUITE_NAME="${TESTSUITE_NAME}.cython"
-    pip install "Cython>=0.27.2,<0.28"
+    pip install "Cython>=0.29.15,<3.0"
     cd pylib/; python setup.py build_ext --inplace
     cd ${WORKSPACE}
 else
